@@ -350,7 +350,7 @@ static int io_open_chunk (struct io_thread_arg *arg, uint64_t chunk_no,
 {
   char name[17];
   int fd;
-  struct stat st;
+  struct stat st, st0;
   struct timespec cooldown;
 
   snprintf(name, sizeof(name), "%016llx", (unsigned long long) chunk_no);
@@ -366,7 +366,7 @@ static int io_open_chunk (struct io_thread_arg *arg, uint64_t chunk_no,
     if (io_lock_chunk(fd, F_RDLCK, start_offs, end_offs) != 0)
       goto ERROR1;
 
-    if (fstatat(arg->cachedir_fd, name, &st, 0) != 0) {
+    if (fstatat(arg->cachedir_fd, name, &st0, 0) != 0) {
       if (errno != ENOENT) {
         logerr("fstatat(): %s", strerror(errno));
         goto ERROR1;
@@ -380,6 +380,16 @@ static int io_open_chunk (struct io_thread_arg *arg, uint64_t chunk_no,
       continue;
     }
 
+    if (fstat(fd, &st) != 0) {
+      logerr("fstat(): %s", strerror(errno));
+      goto ERROR1;
+    }
+
+    if (st.st_ino != st0.st_ino) {
+      /* the file we opened and the current file on disk are not the same */
+      goto ERROR1;
+    }
+
     if (st.st_size == CHUNKSIZE)
       break;
 
@@ -389,7 +399,7 @@ static int io_open_chunk (struct io_thread_arg *arg, uint64_t chunk_no,
     if (io_lock_chunk(fd, F_WRLCK, 0, CHUNKSIZE) != 0)
       goto ERROR1;
 
-    if (fstatat(arg->cachedir_fd, name, &st, 0) != 0) {
+    if (fstatat(arg->cachedir_fd, name, &st0, 0) != 0) {
       if (errno != ENOENT) {
         logerr("fstatat(): %s", strerror(errno));
         goto ERROR1;
@@ -403,6 +413,16 @@ static int io_open_chunk (struct io_thread_arg *arg, uint64_t chunk_no,
       continue;
     }
 
+    if (fstat(fd, &st) != 0) {
+      logerr("fstat(): %s", strerror(errno));
+      goto ERROR1;
+    }
+
+    if (st.st_ino != st0.st_ino) {
+      /* the file we opened and the current file on disk are not the same */
+      goto ERROR1;
+    }
+
     if (st.st_size == CHUNKSIZE)
       break;
 
