@@ -11,4 +11,4 @@ nbd-client -N "$DEVNAME" -b "$BLOCKSIZE" -p -u "$ADDRESS" "$DEVICE" && \
 # file system check!
 fsck -v "$DEVICE" && \
 # mount it
-mount -t ext4 -o journal_async_commit "$DEVICE" "$MNTPOINT"
+mount -t ext4 -o journal_async_commit,stripe=2048 "$DEVICE" "$MNTPOINT"
